Module plugin

Module plugin 

Re-exports

pub use ui::ArcSwapStorage;
pub use ui::RwLockStorage;
pub use ui::UiContext;

Modules

ui

Structs

GuiRegistration
PluginContext
PluginRegistration
RenderJob
RendererRegistration
Schedule
A collection of systems, and the metadata and executor needed to run them in a certain order under certain conditions.
SystemRegistration

Enums

PluginReport

Traits

DynGui
DynPlugin
DynRenderer
Gui
Plugin
Renderer
Skeleton
SystemContributor
SystemPlugin
UiState
Trait for plugin-defined UI state that can be sent across threads and downcast.

Type Aliases

PluginId
RenderTask