Re-exports
pub use ui::ArcSwapStorage;pub use ui::RwLockStorage;pub use ui::UiContext;
Modules
Structs
- GuiRegistration
- Plugin
Context - Plugin
Registration - Render
Job - Renderer
Registration - Schedule
- A collection of systems, and the metadata and executor needed to run them in a certain order under certain conditions.
- System
Registration
Enums
Traits
- DynGui
- DynPlugin
- DynRenderer
- Gui
- Plugin
- Renderer
- Skeleton
- System
Contributor - System
Plugin - UiState
- Trait for plugin-defined UI state that can be sent across threads and downcast.